@@ -108,7 +108,7 @@ def _arrays_to_trains(arrays, **meta):
             meta['duration'] = np.array(meta['duration']).astype(float)
 
 
-    trains = {'spikes': [np.array(a) for a in arrays]}
+    trains = {'spikes': [np.array(a, dtype=float) for a in arrays]}
     trains.update(meta)
 
     trains = pd.DataFrame(trains)
@@ -234,9 +234,12 @@ def accumulate(spike_trains, ignore=None, keep=None):
 
 
 
-def trim(spike_trains, start, stop):
-    """Remove all spikes outside of the (`start`, `stop`) range."""
+def trim(spike_trains, start=0, stop=None):
+    """Trim the spike trains.
 
+    Remove all spikes outside of the (`start`, `stop`) range.
+
+    """
     tmin = start
 
     if stop is None:
